# CODE: DISPERSAL IN THE URBAN MATRIX: ASSESSING THE INFLUENCE OF LANDSCAPE
# PERMIABILITY ON THE SETTLEMENT PATTERNS OF BREEDING SONGBIRDS

#============================================================================*
# --- Description ---- 
#============================================================================*

# This code provides all of the steps for processing and evaluating resight data
# and the association of resights with suitability and permeability surfaces in 
# program R. We use of section headers throughout this script -- as such, using 
# R Studio to access this code is highly adviseable. Please note that impervious
# (imp) and canopy cover (can) raster data files are too large to provide as a
# supplemental. These data can be obtained from Multi-Resolution Land
# Characteristics Consortium at www.mrlc.gov.

#============================================================================*
# --- Set up ---- 
#============================================================================*

options(stringsAsFactors = FALSE)

# Smart require checks to see if the libraries are present, installs them if
# necessary, and loads them:

smartRequire <- function(packages){
  # Get vector of packages listed that aren't on the current computer
  packagesToInstall <- packages[!packages %in% rownames(installed.packages())]
  if(length(packagesToInstall > 0)){
    install.packages(packagesToInstall, dependencies = TRUE)
  }
  lapply(packages, require, character.only = TRUE)
}

smartRequire(
  c('raster', 'gdistance', 'tidyverse', 'lubridate','geosphere',
    'ggplot2', 'unmarked', 'stringr', 'AICcmodavg',
    'MuMIn', 'lme4', 'RColorBrewer')
)

# Override some functions:

extract <- raster::extract

select <- dplyr::select

rename <- dplyr::rename

# General function converts NA to zero:

naToZero <- function(x) ifelse(is.na(x), 0 , x)

# General function to scale a variable (vector):

zScale <- function(x) (x - mean(x))/sd(x)

# Read csv, then tbl (because sometimes there are parsing problems with read_csv):

readTbl <- function(x) read.csv(x) %>% tbl_df

# Standard error:

se <- function(x) sd(x)/sqrt(length(x))

# Projection for longLat data:

llPrj <- '+init=epsg:4326 +proj=longlat +datum=WGS84 +no_defs +ellps=WGS84 +towgs84=0,0,0 '

# Get centroids file:

centroids <- read.csv('centroids.csv')

# Projection for utm data:

utmPrj <- '+proj=utm +datum=WGS84 +zone=18 +ellps=WGS84'

# Extent:

studyExtent <- extent(c(-77.6, -75.8, 38.35, 39.72))

# Function to fill (unfortunate) holes in a raster:

fillHoles <- function(croppedRaster){
  fillList <- vector('list', length = 20)
  for(i in 2:20){
    fillList[[1]] <- croppedRaster 
    fillList[[i]] <- fillList[[i-1]] %>%
      focal(w = matrix(1,5,5), NAonly = TRUE, fun = mean, na.rm = TRUE)
  }
  return(fillList[[20]])
}

# Rasters:

imp <- raster('imp') %>%
  crop(studyExtent) %>%
  trim %>%
  fillHoles

can <- raster('can') %>%
  crop(studyExtent) %>%
  trim %>%
  fillHoles

# Process land cover:

rStackScaled <- list(
  # Impervious surface:
  imp = focal(
    imp,
    w = matrix(1, nrow=3, ncol=3),
    fun = mean, na.rm = TRUE),
  # Canopy cover:
  can = focal(
    can,
    w = matrix(1, nrow=3, ncol=3),
    fun = mean, na.rm = TRUE),
  # RMS:
  rms = focal(
    can,
    w = matrix(1, nrow=3, ncol=3),
    fun = function(x){
      sqrt(sum((x-mean(x))^2)/length(x))
    }
  )
) %>% stack %>%
  scale

#============================================================================*
# --- Point count analysis ---- 
#============================================================================*

#----------------------------------------------------------------------------*
# ---- Functions used ----
#----------------------------------------------------------------------------*

# Function to make a point count frame (counts, obsCovs) for a given species:

makeCountFrame <- function(spp){
  countFrame <- pc %>%
    mutate(year = year(date)) %>%
    arrange(site) %>%
    group_by(site, date, observer, year) %>%
    summarize(count = sum(count[species == spp])) %>%
    ungroup
  spMat <- countFrame %>%
    select(site, year, count) %>%
    distinct %>% 
    spread(year, count, fill = NA) %>%
    select(-site) %>%
    as.matrix
  obsCovs <- list(
    obs = countFrame %>%
      select(site, year, observer) %>%
      spread(year, observer, fill = NA) %>%
      select(-site) %>%
      data.frame
  )
  return(
    list(
      y = spMat,
      obsCovs = obsCovs
    )
  )
}

# Function to make an unmarked frame for point count data:

getUMF <- function(spp){
  countList <- makeCountFrame(spp)
  unmarkedFramePCount(
    y = countList$y,
    siteCovs = siteCovs,
    obsCovs = countList$obsCovs
  )
}

# Function to run abundance models for a given species:

abundModListFun <- function(spp){
  modelData <- getUMF(spp)
  mList <- list(
    null = pcount(
      ~1 ~1,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    obs =  pcount(
      ~obs ~1,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    imp =  pcount(
      ~obs ~imp,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impCan =  pcount(
      ~obs ~imp + can,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impRms =  pcount(
      ~obs ~imp + rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impCanRms =  pcount(
      ~obs ~imp + can + rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    can =  pcount(
      ~obs ~can,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    canRms =  pcount(
      ~obs ~can + rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impXcan =  pcount(
      ~obs ~imp*can,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impXcanRms =  pcount(
      ~obs ~imp*can + rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impXrms =  pcount(
      ~obs ~imp*rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impXrmsCan =  pcount(
      ~obs ~imp*rms + can,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    impXrmsCanXrms =  pcount(
      ~obs ~imp*rms + can*rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    canXrms = pcount(
      ~obs ~can*rms,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    ),
    canXrmsImp = pcount(
      ~obs ~can*rms + imp,
      data = modelData, K = 50, mixture = 'P', engine = 'C'
    )
  )
  return(mList)
}

# Function to run models and return objects of interest for a given species:

runModels <- function(spp){
  mods <- abundModListFun(spp)
  fmList <- fitList(fits = mods) #get.models(mods, subset = TRUE)
  modSelection <- modSel(fmList, nullmod = "null")
  return(
    list(modList = fmList,
         modSelection = modSelection
    )
  )
}

#----------------------------------------------------------------------------*
# ---- Prepare point count data ----
#----------------------------------------------------------------------------*

# Read data:

pc <- readTbl('pointCounts.csv')

pointsPc <- readTbl('pointCountSites.csv')

# Make point count locations spatial:

pointsSp <- pointsPc %>%
  select(lon, lat) %>%
  SpatialPoints(CRS(llPrj))

# Extract covariate data to points:

siteCovs <- bind_cols(
  pointsPc,
  raster::extract(rStackScaled,pointsSp) %>%
    as.data.frame %>%
    setNames(c('imp', 'can', 'rms'))) %>%
  select(imp, can, rms) %>%
  data.frame

#----------------------------------------------------------------------------*
# --- Point count analysis ---- 
#----------------------------------------------------------------------------*

# Run models for each species:

species <- c('amro', 'grca', 'hosp', 'noca')

modelOutList <- vector('list', length = length(species))

names(modelOutList) <- species

for(i in 1:length(species)){
  modelOutList[[i]] <- runModels(species[i])
}

#============================================================================*
# --- Suitability and permeability surface preparation ---- 
#============================================================================*

#----------------------------------------------------------------------------*
# --- Functions used ---- 
#----------------------------------------------------------------------------*

# Function to get and project centroid:

getCentroid <- function(bandingStation){
  centroidsFile <- centroids %>%
    filter(site == bandingStation)
  centroidsSp <- SpatialPointsDataFrame(
    coords = data.frame(centroidsFile$lon, centroidsFile$lat),
    data = data.frame(centroidsFile$site),
    proj4string = crs(imp))
  return(centroidsSp)
}

# Function to get banding station extent: 

getBandingStationExtent <- function(centroidSp, distance = 1700){
  centroidPrj <- spTransform(centroidSp, CRS(utmPrj))
  stationCoords <- centroidPrj@coords %>%
    data.frame %>%
    dplyr::rename(X = centroidsFile.lon,
                  Y = centroidsFile.lat)
  coordMat <- bind_rows(
    stationCoords - distance,
    stationCoords + distance) %>%
    as.matrix %>%
    t
  extent(coordMat) %>%
    raster(crs = utmPrj) %>%
    projectExtent(crs = llPrj) %>%
    extent
}

# Function to get land cover rasters for banding station extent:

getLandCover <- function(bandingStation, rStack){
  centroid <- getCentroid(bandingStation)
  stationExtent <- getBandingStationExtent(centroid, 1700)
  
  impCrop <- crop(rStack$imp, stationExtent) %>% trim
  canCrop <- crop(rStack$can, stationExtent) %>% trim
  rmsCrop <- crop(rStack$rms, stationExtent) %>% trim
  
  rStackStation <- stack(impCrop, canCrop, rmsCrop)
  return(rStackStation)
}

scaleRaster01 <- function(x){
  rMin <- cellStats(x, min)
  rMax <- cellStats(x, max)
  return(
    (x - rMin)/(rMax - rMin)
  )
}

# Function to scale any vector to between zero and one:

scale01 <- function(x){
  (x - min(x))/(max(x) - min(x))
}

# Function to generate scaled suitability and permeability rasters:

cdRasterFun <- function(hSuitRaster, bandingStation){
  # Banding station location:
  centroid <- getCentroid(bandingStation)
  # Euclidean distance walk:
  eucTransition <- transition(
    hSuitRaster, function(x){1}, directions = 16) %>%
    geoCorrection %>%
    accCost(centroid)
  # Weighted cost walk:
  weightedTransition <- transition(
    hSuitRaster, function(x) 1/mean(x), directions = 16) %>%
    geoCorrection %>%
    accCost(centroid)
  # Make permeability raster:
  permeability <- scale(weightedTransition/eucTransition)
  suitability <- scale(hSuitRaster)
  # Return stack:
  stationStack <- stack(permeability, suitability)
  names(stationStack) <- c('permeability', 'suitability')
  return(stationStack)
}

#----------------------------------------------------------------------------*
# --- Prepare suitability and permeability surfaces ---- 
#----------------------------------------------------------------------------*

# Predict point counts for each banding station and species:

bandingStations <- c('br', 'go', 'hunter', 'marra', 'nmnh', 'rc')

species <- c('amro', 'grca', 'hosp','noca')

suitabilityRasters <- vector('list', length = length(bandingStations))
names(suitabilityRasters) <- bandingStations

for(i in 1:length(bandingStations)){
  landCoverStack <- getLandCover(bandingStations[i], rStackScaled) %>%
    trim
  speciesRasters <- vector('list', length = length(species))
  names(speciesRasters) <- species
  for(j in 1:length(species)){
    speciesModel <- modelOutList[[species[j]]]$modList
    predictions <- predict(
      speciesModel,
      type = 'state',
      newdata = as.data.frame(values(landCoverStack))
    ) %>%
      .$Predicted %>%
      scale01
    suitability <- raster(landCoverStack)
    values(suitability) <- predictions
    speciesRasters[[j]] <- suitability
  }
  suitabilityRasters[[i]] <- speciesRasters
}

# Estimate suitability and permeability for each banding station and species:

bandingStations <- c('br', 'go', 'hunter', 'marra', 'nmnh', 'rc')

species <- c('amro', 'grca', 'hosp','noca')

stationRasters <- vector('list', length = length(bandingStations))
names(stationRasters) <- bandingStations

for(i in 1:length(bandingStations)){
  bStation <- bandingStations[i]
  suitabilityStation <- suitabilityRasters[[bStation]]
  speciesRasters <- vector('list', length = length(species))
  names(speciesRasters) <- species
  for(j in 1:length(species)){
    suitabilityPrediction <- suitabilityStation[[species[j]]]
    speciesRasters[[j]] <- cdRasterFun(
      suitabilityPrediction, bStation
    )
  }
  stationRasters[[i]] <- speciesRasters
}

#============================================================================*
# ---- Resight analysis ----
#============================================================================*

# Function to get samples for a given banding station and species:

getSamplesForCentroid <- function(bandingStation, spp){
  # Samples at some netting locations to remove:
  netSamples <- samplingLocations %>%
    filter(netLoc == bandingStation)
  if(nrow(netSamples) == 0){
    netSamples <- 'doesNotApply'
  } else {
    netSamples <- netSamples$sampleId
  }
  # Banding station location:
  centroid <- getCentroid(bandingStation)
  # Resights associated with the banding station:
  resightsStation <- resights %>%
    filter(station == bandingStation,
           sp == spp,
           !sampleId %in% netSamples)
  # Samples including resights
  samples <- bind_rows(
    resightsStation,
    samplingLocations %>%
      filter(!sampleId %in% resightsStation$sampleId,
             netLoc != bandingStation,
             !sampleId %in% netSamples) %>%
      select(-netLoc) %>%
      group_by(sampleId) %>%
      mutate(lon = mean(lon), lat = mean(lat)) %>%
      ungroup(sampleId) %>%
      distinct %>%
      transmute(
        sampleId = sampleId,
        station = bandingStation,
        sp = spp,
        lon = lon,
        lat = lat,
        bNum = NA,
        age = NA,
        sex = NA,
        year = NA,
        resight = 0
      )
  )
  # Add distance to banding station:
  samplingSpatial <- samples %>%
    select(lon, lat) %>%
    SpatialPoints(proj4string = CRS(llPrj))
  samples$stationDist <- as.numeric(distm(samplingSpatial, centroid))
  # Subset to samples less than 1500 m (to isolate banding station samples):
  stationSamples <- samples %>%
    select(sampleId:bNum, resight, stationDist) %>%
    filter(stationDist <= 1500,
           stationDist >= 150)
  return(stationSamples)
}

# Function to get permeability and suitability values for a given banding
# station and species:

getResightFrame <- function(bandingStation, spp){
  # Get sampling locations for banding station:
  stationSamples <- getSamplesForCentroid(bandingStation, spp)
  # Make station samples spatial:
  stationSp <- stationSamples %>%
    select(lon, lat) %>%
    SpatialPoints(proj4string = CRS(llPrj))
  # Extract permeability and suitability values to samples:
  rasterValues <- raster::extract(
    stationRasters[[bandingStation]][[spp]],
    stationSp) %>%
    as.data.frame
  # Bring in the resight data and return:
  return(
    bind_cols(stationSamples, rasterValues) %>%
      select(sampleId:bNum, stationDist, permeability,
             suitability, resight) %>%
      mutate(permeability = permeability,
             suitability = suitability)
  )
}

#----------------------------------------------------------------------------*
# ---- Resight data preparation ----
#----------------------------------------------------------------------------*

# Get locations of samples:

samplingLocations <- read_csv('samplingLocations.csv') %>%
  select(sampleId:netLoc)

# Get resight data:

resights <- read_csv('resights.csv') %>%
  filter(center != 1) %>%
  select(station:resight) %>%
  left_join(samplingLocations %>%
              select(lon, lat, sampleId),
            by = c('lon', 'lat')) %>%
  select(sampleId, station:resight) %>%
  distinct

# Get data for each station and species:

resightStationList <- vector('list', length = length(bandingStations))
species <- c('amro', 'grca', 'hosp', 'noca')

for(i in 1:length(bandingStations)){
  resightSpeciesList <- vector('list', length = length(bandingStations))
  for(j in 1:length(species)){
    resightFrame <- getResightFrame(bandingStations[i], species[j])
    if(!is.null(resightFrame)){
      if(sum(resightFrame$resight > 0)){
        resightSpeciesList[[j]] <- resightFrame
      }
    }
  }
  resightStationList[[i]] <- bind_rows(resightSpeciesList)
}

# Bind list and create sampling frame:

samplingOutput <- bind_rows(resightStationList) %>%
  group_by(sp, station) %>%
  mutate(longestRs = max(stationDist[resight == 1])) %>%
  ungroup %>%
  filter(stationDist <= longestRs) %>%
  select(-longestRs)  %>%
  group_by(sp, station) %>%
  filter(!is.na(permeability)) %>%
  ungroup %>%
  distinct %>%
  group_by(sampleId, station, sp) %>%
  summarize(permeability = mean(permeability),
            suitability = mean(suitability),
            resight = mean(resight)) %>%
  ungroup

#----------------------------------------------------------------------------*
# ---- Permeability suitability models ----
#----------------------------------------------------------------------------*

modRunPermeabilitySuitability <- function(spp){
  modelData <- samplingOutput %>% 
    filter(sp == spp) %>%
    rename(hSuit = suitability) %>%
    select(sampleId, station, permeability, hSuit, resight) %>%
    distinct
  mList <- list(
    null = glmer(resight ~ 1 + (1|station), 
                 data = modelData,
                 family = binomial, 
                 control = glmerControl(optimizer = 'bobyqa'),
                 nAGQ = 3),
    additive = glmer(resight ~ hSuit+permeability +(1|station), 
                     data = modelData,
                     family = binomial, 
                     control = glmerControl(optimizer = 'bobyqa'),
                     nAGQ = 3),
    suitability = glmer(resight ~ hSuit +(1|station), 
                        data = modelData,
                        family = binomial, 
                        control = glmerControl(optimizer = 'bobyqa'),
                        nAGQ = 3),
    permeability = glmer(resight ~ permeability +(1|station), 
                         data = modelData,
                         family = binomial, 
                         control = glmerControl(optimizer = 'bobyqa'),
                         nAGQ = 3))
  outList <- list(mList, aictab(mList))
  names(outList)<-c('modelList', 'aicTable')
  return(outList)
}

# Run models:

permSuitModList <- vector('list', length = length(species))
names(permSuitModList) <- species

for(i in 1:length(species)){
  permSuitModList[[i]] <- modRunPermeabilitySuitability(species[i])
}

#============================================================================*
# ---- translocation ----
#============================================================================*
landCover <- c('Rural', 'Suburban', 'Urban')

Bird1<- c(5, 1, 9)
Bird2<- c(7, 3, 14)

trans<- data.frame(landCover, Bird1, Bird2) %>%
  gather(Bird, days, Bird1:Bird2) %>%
  select(landCover, days)

glm(days~1, data = trans) %>% AIC

glm(days~landCover, data = trans) %>% AIC

1-deviance(glm(days~landCover, data = trans))/deviance(glm(days~1, data = trans))

#============================================================================*
# ---- Figures ----
#============================================================================*

# Figure 1: Plot of suitability rasters, scaled from 0 to 1 across stations

# Figure 2: Permeability and suitability plots for Spring Park with sampling
# points

# Figure 3: Suitability and permeability z-scores by species

# Supplemental figure: Boxplot of distance from banding station for resighted
# individuals observed greater than 150 m from the banding station.

#----------------------------------------------------------------------------*
# ---- Figure 1 ----
#----------------------------------------------------------------------------*

# Predict suitability for each banding station and species:

bandingStations <- c('br', 'go', 'hunter', 'marra', 'nmnh', 'rc')

species <- c('amro', 'grca', 'hosp','noca')

suitabilityFrameList <- vector('list', length = length(bandingStations))

for(i in 1:length(bandingStations)){
  # Get land cover for station:
  landCoverStack <- getLandCover(bandingStations[i], rStackScaled) %>%
    trim
  speciesFrameList <- vector('list', length = length(species))
  for(j in 1:length(species)){
    # Get species models:
    speciesModel <- modelOutList[[species[j]]]$modList
    # Predict to raster:
    predictions <- predict(
      speciesModel,
      type = 'state',
      newdata = as.data.frame(values(landCoverStack))
    ) %>%
      .$Predicted
    suitability <- raster(landCoverStack)
    values(suitability) <- predictions
    # Raster to data frame:
    speciesFrameList[[j]] <- suitability %>%
      rasterToPoints %>%
      data.frame %>%
      mutate(sp = species[j])
  }
  suitabilityFrameList[[i]] <- bind_rows(speciesFrameList) %>%
    mutate(station = bandingStations[i])
}

# Make into plot-ready data frame:

suitabilityFrame <- bind_rows(suitabilityFrameList) %>%
  tbl_df %>%
  mutate(
    Species = factor(
      sp,
      labels = c('American Robin', 'Gray Catbird',
                 'House Sparrow', 'Northern Cardinal')
    ),
    station = factor(
      station,
      levels = c(
        'rc', 'marra', 'hunter',
        'go', 'br', 'nmnh'
      ),
      labels = c(
        'Rock Creek','Spring Park', 'Opal Daniels', 
        'Bethesda','Foggy Bottom', 'National Mall'
      )
    )
  ) %>%
  group_by(station) %>%
  mutate(
    xAxis = x - min(x),
    yAxis = y - min(y)
  ) %>%
  ungroup %>%
  group_by(Species) %>%
  mutate(Suitability = scale01(layer))

# Plot rasters, suitability:

myPalette <- colorRampPalette(rev(brewer.pal(11, "Spectral")))
sc <- scale_fill_gradientn(colours = myPalette(100), limits=c(0, 1))

suitabilityRawPlot <- suitabilityFrame %>%
  # filter(station == bandingStation) %>%
  ggplot(aes(xAxis, yAxis)) + 
  geom_raster(aes(fill = Suitability), alpha = 1) +
  facet_grid(. ~ station ~ Species, scales = 'free') +
  sc +
  labs(x = 'Longitude', y = 'Latitude') +
  theme_bw() + 
  theme(axis.title = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        strip.text = element_text(size = rel(0.6)),
        legend.title = element_text(size = rel(0.6)),
        legend.text = element_text(size = rel(0.6)))

suitabilityRawPlot
ggsave('suitabilityRaw.png', 
       width = 5.8, height = 7, units = 'in')

#----------------------------------------------------------------------------*
# ---- Figure 2 ----
#----------------------------------------------------------------------------*

# Function to convert centroid to data frame:

centroidToDf <- function(bandingStation){
  getCentroid(bandingStation)@coords %>%
    data.frame %>%
    rename(x = centroidsFile.lon,
           y = centroidsFile.lat) %>%
    mutate(Location = as.factor('Banding station'))
}

# Spring Park suitability rasters:

sPark <- stationRasters$marra

# Points:

sParkPoints <- bind_rows(resightStationList) %>%
  filter(station == 'marra') %>%
  group_by(sp) %>%
  mutate(longestRs = max(stationDist[resight == 1])) %>%
  ungroup %>%
  filter(stationDist >= 150) %>%
  filter(stationDist <= longestRs) %>%
  select(-longestRs)  %>%
  group_by(sp, station) %>%
  filter(!is.na(permeability)) %>%
  ungroup %>%
  distinct %>%
  transmute(
    Species = factor(
      sp,
      labels = c('American Robin', 'Gray Catbird',
                 'House Sparrow', 'Northern Cardinal')
    ),
    x = lon,
    y = lat,
    Observation = as.factor(resight)
  )

# Suitability and permeability raster frames for each species:

speciesFrameList <- vector('list', length = length(bandingStations))

for(i in 1:length(species)){
  # Get species raster, convert to data frame:
  speciesFrameList[[i]] <- sPark[[species[i]]] %>%
    rasterToPoints %>%
    data.frame %>%
    tbl_df %>%
    mutate(sp = species[i])
}

# Plot-ready data frame:

permSuitFrame <- bind_rows(speciesFrameList) %>%
  tbl_df %>%
  mutate(
    Species = factor(
      sp,
      labels = c('American Robin', 'Gray Catbird',
                 'House Sparrow', 'Northern Cardinal')
    )
  )

# Plot rasters, permeability:

permPlot <- permSuitFrame %>%
  mutate(Permeability = permeability) %>%
  ggplot(aes(x, y)) + 
  geom_raster(aes(fill = Permeability), alpha = 1) +
  facet_grid(. ~ Species, scales = 'free') +
  sc +
  labs(x = 'Longitude', y = 'Latitude') +
  theme_bw() + 
  theme(axis.title = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        strip.text = element_text(size = rel(0.6)),
        legend.title = element_text(size = rel(0.6)),
        legend.text = element_text(size = rel(0.6)))

permPlot +
  geom_point(data = sParkPoints,
             aes(x = x, y = y), color = 'black', 
             size = 1.5) +
  geom_point(data = sParkPoints,
             aes(x = x, y = y, color = Observation), 
             size = 1) +
  scale_color_manual(values = c('red', 'blue'), guide = FALSE) +
  geom_point(data = centroidTodf('marra'),
             aes(x = x, y = y),
             color = 'white',
             shape = 17,
             size = 2.75) +
  geom_point(data = centroidTodf('marra'),
             aes(x = x, y = y),
             color = 'black',
             shape = 17,
             size = 2)

ggsave('permPlot.png', 
       width = 7, height = 1.75, units = 'in')

# Plot rasters, suitability:

suitPlot <- permSuitFrame %>%
  mutate(Suitability = suitability) %>%
  ggplot(aes(x, y)) + 
  geom_raster(aes(fill = Suitability), alpha = 1) +
  facet_grid(. ~ Species, scales = 'free') +
  sc +
  labs(x = 'Longitude', y = 'Latitude') +
  theme_bw() + 
  theme(axis.title = element_blank(),
        axis.text = element_blank(),
        axis.ticks = element_blank(),
        strip.text = element_text(size = rel(0.6)),
        legend.title = element_text(size = rel(0.6)),
        legend.text = element_text(size = rel(0.6)))

suitPlot +
  geom_point(data = sParkPoints,
             aes(x = x, y = y), color = 'black', 
             size = 1.5) +
  geom_point(data = sParkPoints,
             aes(x = x, y = y, color = Observation), 
             size = 1) +
  scale_color_manual(values = c('red', 'blue'), guide = FALSE) +
  geom_point(data = centroidTodf('marra'),
             aes(x = x, y = y),
             color = 'white',
             shape = 17,
             size = 2.75) +
  geom_point(data = centroidTodf('marra'),
             aes(x = x, y = y),
             color = 'black',
             shape = 17,
             size = 2)


ggsave('suitPlot.png', 
       width = 7, height = 1.75, units = 'in')

#----------------------------------------------------------------------------*
# ---- Figure 3 ----
#----------------------------------------------------------------------------*

# Point data:

dataPoints <- bind_rows(
  samplingOutput %>%
    select(sp, permeability, resight) %>%
    mutate(measure = 'Permeability') %>%
    rename(value = permeability),
  samplingOutput %>%
    select(sp, suitability, resight) %>%
    mutate(measure = 'Suitability') %>%
    rename(value = suitability)
) %>%
  distinct %>%
  mutate(
    measure = factor(measure),
    Species = factor(
      sp,
      labels = c('American Robin', 'Gray Catbird',
                 'House Sparrow', 'Northern Cardinal')
    ),
    resight = factor(resight)
  ) %>%
  group_by(Species, measure) %>%
  mutate(value = zScale(value)) %>%
  ungroup 

# Point summary data:

dataSummary <- dataPoints %>%
  group_by(Species, measure, resight) %>%
  summarize(
    mean = mean(value),
    se = se(value)
  ) %>%
  mutate(
    lcl = mean - se*1.96,
    ucl = mean + se*1.96
  ) %>%
  ungroup

# Plot results:

suitConnZplot <-  ggplot(
  dataSummary,
  aes(x = measure, y = mean, color = resight, group = resight)
) +
  geom_hline(aes(yintercept = 0), linetype = 2) +
  geom_point(
    data = dataPoints,
    aes(x = measure, y = value, 
        color = resight, group = resight),
    alpha = 0.15,
    size = 8,
    position=position_dodge(width = .5)
  ) +
  geom_errorbar(
    aes(ymax = ucl, ymin = lcl, width = 0, group = resight),
    size = 5, 
    position=position_dodge(width = .5),
    color = 'black'
  ) +
  geom_errorbar(
    aes(ymax = ucl, ymin = lcl, width = 0, group = resight),
    size = 2, 
    position=position_dodge(width = .5)
  ) +
  facet_wrap(~Species, scales = 'free_y') +
  geom_point(
    size = 8,
    color = 'black',
    position=position_dodge(width = .5)
  ) +
  geom_point(
    size = 5,
    position=position_dodge(width = .5)
  ) +
  scale_color_manual(name = 'Survey\nResults\n', values = c('red', 'blue')) +
  scale_y_continuous(limits = c(-1.25,1.25))+
  labs(x = 'Habitat metric', y = 'Suitability or Permeability\n(z-score)') +
  theme_classic()+
  theme(
    axis.title = element_text(size = rel(1.8)),
    axis.title.x = element_text(vjust = -1.4,face = 'bold'), 
    axis.title.y = element_text(vjust = 1.7),
    axis.text = element_text(size = rel(1.8)),
    strip.background = element_rect(fill = 'grey95', color = 'gray75'),
    strip.text.x = element_text(size = rel(2.1)),
    plot.margin = grid::unit(c(1,1,1,1),'cm')
  )

suitConnZplot
ggsave('suitConnPlot.png', 
       width = 11, height = 7, units = 'in')  

#----------------------------------------------------------------------------*
# ---- Supplemental figure, resight by distance ----
#----------------------------------------------------------------------------*

bind_rows(resightStationList) %>%
  filter(resight == 1) %>%
  mutate(
    Species = factor(
      sp,
      labels = c('American Robin', 'Gray Catbird',
                 'House Sparrow', 'Northern Cardinal')
    )
  ) %>%
  ggplot(aes(x = Species, y = stationDist)) +
  geom_boxplot(fill = 'lightgray') +
  theme_classic() +
  ylab('Distance from banding station (m)') +
  theme(
    axis.title = element_text(size = rel(1.8)),
    axis.title.x = element_text(vjust = -1.2,face = 'bold'), 
    axis.title.y = element_text(vjust = 1.7),
    axis.text = element_text(size = rel(1.8)),
    strip.background = element_rect(fill = 'grey95', color = 'gray75'),
    strip.text.x = element_text(size = rel(2.1)),
    plot.margin = grid::unit(c(1,1,1,1),'cm')
  )

ggsave('sampleByDistSupplement.png', 
       width = 11, height = 7, units = 'in')  
